;; Generated package description from vertico-posframe.el  -*- no-byte-compile: t -*-
(define-package "vertico-posframe" "0.9.1" "Using posframe to show Vertico" '((emacs "26.0") (posframe "1.4.0") (vertico "2.5")) :commit "6ceeeff4c13663083bfaa4193879191a0c8c57de" :authors '(("Feng Shu" . "tumashu@163.com")) :maintainer '("Feng Shu" . "tumashu@163.com") :keywords '("abbrev" "convenience" "matching" "vertico") :url "https://github.com/tumashu/vertico-posframe")
